Create a transitions loader
TransitionsLoader.RdValidates a BatchBirdFlowTrainer() and constructs a TransitionsLoader()
that can load and split combined movement data for evaluation/tuning.
TransitionsLoader.RdValidates a BatchBirdFlowTrainer() and constructs a TransitionsLoader()
that can load and split combined movement data for evaluation/tuning.