Skip to contents

Batch calculate flux in parallel using slurm

Usage

batch_flux(
  model_paths,
  flux_paths = NULL,
  base_path = NULL,
  memory = 12,
  walltime = 180,
  show_progress = TRUE
)

Arguments

model_paths

The path to one or more BirdFlow models saved either as HDF5 or RDS files.

flux_paths

Paths (ending in ".rds") to save flux to. It should be the same length as model_paths or NULL in which case "_flux.rds" will be appended to model_paths after removing the extension.

base_path

The directory in which the batch tools registry directory should be created (used to manage the run). If NULL the directory of the first path in model_paths will be used. Either way the registry directory will be a concatenation of "batch_flux", the date, and "_mf".

memory

GB of memory allocated for each flux calculation.

walltime

Elapsed time in minutes allocated to the job.

show_progress

If TRUE batch_flux() will display a progress bar and wait for all the launched jobs to finish. If FALSE batch_flux() will exit immediately after launching.

Value

Nothing is returned.