Skip to contents

A BirdFlow model collection consists of 1 or more BirdFlow objects each saved to a single .Rds file, an index.Rds file, an index.html file and a index_md5.txt file. This function converts a directory with model .Rds files into a collection. It needs to be run locally to an R session so likely the resulting directory will be synchronized with a server after it is created.

Usage

build_collection_index(
  dir,
  collection_url,
  description = NULL,
  title = "BirdFlowR Model Collection"
)

Arguments

dir

A local directory for containing BirdFlow models saved as .Rds files. The base file name will be used as the model name and other metadata will be extracted from the BirdFlow object.

collection_url

The final URL for the BirdFlow collection (where it will be served).

description

Optional text for an section to be inserted into the markdown document as is and in place of the default description. The intent is to allow describing this particular collection. The first line should start with "## " and the section header, followed by a blank line and description text or additional markdown.

title

The page title. Will appear as a level one heading and as the formal title of the page.

Details

It is primarily intended for use by the BirdFlow team but is exported from the package so anyone can use it.