Skip to contents

Make the list of file sets required by process_file_set()

Usage

combine_together_list(suffix_vec, together_list)

Arguments

suffix_vec

A vector of all possible suffixes in the BBL CSV file download set

together_list

A list, each element of which is a vector of 2 or more CSV file suffixes that need to be analyzed together

Value

A list, each element of which is a vector of CSV file suffixes to analyze at the same time. When one of the vectors has length > 1, it's because one or more ebirdst species spans multiple CSV files