Skip to contents

get_job_efficiency() calls the shell command "seff" on the job ID via batchtools::runOSCommand(), which uses ssh to connect to a login node before running the command. The resulting output is then parsed into an R list.

Usage

get_job_efficiency(id)

Arguments

id

The slurm job ID including an array suffix e.g. "_1" if appropriate.

Value

A list with items:

job_id

slurm job id - without array suffix

array_job_id

slurm job id with array suffix

state

The job state

cores

How many cores did the job use.

cpu_utilized

How much CPU time was used.

cpu_efficiency

CPU efficiency

walltime

Job wall-clock time (ellapsed time) in h:m:s format

memory_utilized

Memory utilized in human readible format with (varying) units

memory_efficiency

Memory efficiency.

mem_gb

Utilized memory in GiB (bytes * 1024^3)

wall_min

Job wall-clock time in decimal minutes