Skip to contents

Calculate the GPU RAM needed for a model

Usage

gpu_ram(bf, max_param_per_gpu_gb = NULL)

Arguments

bf

A BirdFlow model object

max_param_per_gpu_gb

The number of parameters that can be fit with each GB of GPU ram. If NULL, the default the value from BirdFlowR::birdflow_options()` is used. The only reason to set it here is if that value is empirically wrong.

Value

The GB of GPU RAM that was or will be required to fit bf

Examples

bf <- BirdFlowModels::amewoo
gpu_ram(bf)
#> [1] 0.06877368