Skip to contents

Note: I ran this on unity after using devtools::load_all() it seemed to be writing temporary files to the inst/rmd directory. This suggests that it might not work with an installed version of BirdFlowPipeline. If that's the case we'd have to copy the Rmd from the package to a temorary location before knitting.

Usage

make_flux_index(index, html)

Arguments

index

Data frame with columns:

species

eBird species code

common_name

Species common name

scientific

Scientific name

report_exists

TRUE if an html report exists for the species.

rel_link

The relative link to the species report from the index location (html)

html

path to output html index file.

Value

Nothing is returned, a report is created at html

Examples

if (FALSE) { # \dontrun{
index <- readRDS(system.file("rmd/flux_index_example.Rds", package = "BirdFlowPipeline"))
html <- file.path(tempdir(), "index.html")
make_flux_index(index, html)
file.exists(html)
file.remove(html)
} # }