Skip to contents

Make flux report

Usage

make_flux_report(hdf, flux, anim, html, prevlink, nextlink)

Arguments

hdf

path to HDF5 model file

flux

path to flux RDS file

anim

path to abundance and flux animation GIF

html

path to output html file

relative path to the previous species report or NULL if there is none.

relative path to the next species report or NULL if none.

Value

Nothing is returned, a report is created at html