Skip to contents

Process and fit a single model with fixed parameters

Usage

preprocess_and_fit(species, params)

Arguments

species

A species code appropriate for ebirdst::get_species().

params

A parameter list similar to that returned by set_pipeline_params() but for this function each of the grid_search parameter list items should be a single value.

Value

This function is called for the side affect of creating a fitted hdf5 model file.