Skip to contents

Quick visualize a spring migration routes simulation from eval_metrics by row number

Usage

quick_visualize_routes(
  i,
  n = 10,
  season = "prebreeding",
  df = eval_metrics,
  dir = hdf_dir
)

Arguments

i

row number in df from which to extract model

n

number of routes to simulate for visualization

season

season for which to simulate route, parseable by BirdFlowR::lookup_season_timesteps()

df

a eval_metrics produced by evaluate.BatchBirdFlowEvaluator()

dir

hdf5 directory from params list. Need to refactor some of these arguments

Value

side effect is an interactive plot