Skip to contents

Calculate route summary statistics

Usage

rts_stats(rts, remove_head_and_tail_stationaries = FALSE)

Arguments

rts

BirdFlowRoutes object output from BirdFlowR::route() or a data frame with the same data.

remove_head_and_tail_stationaries

Whether to remove the head and tail Stationary period. Useful when the calculaton is across multiple seasons ( e.g., From nonbreeding to breeding)

Value

a list of mean summary statistics