Make the list of file sets required by process_file_set()
combine_together_list.RdMake the list of file sets required by process_file_set()
Value
A list, each element of which is a vector of CSV file suffixes to analyze at the same time. When one of the vectors has length > 1, it's because one or more ebirdst species spans multiple CSV files