Calculate the GPU RAM needed for a model
gpu_ram.RdCalculate the GPU RAM needed for a model
Arguments
- bf
A BirdFlow model object
- max_param_per_gpu_gb
The number of parameters that can be fit with each GB of GPU ram. If
NULL, the default the value fromBirdFlowR::birdflow_options()` is used. The only reason to set it here is if that value is empirically wrong.
Examples
bf <- BirdFlowModels::amewoo
gpu_ram(bf)
#> [1] 0.06877368