Make html index file for flux reports
make_flux_index.RdNote: I ran this on unity after using devtools::load_all() it
seemed to be writing temporary files to the inst/rmd directory. This
suggests that it might not work with an installed version of BirdFlowPipeline.
If that's the case we'd have to copy the Rmd from the package to a temorary
location before knitting.
Examples
if (FALSE) { # \dontrun{
index <- readRDS(system.file("rmd/flux_index_example.Rds", package = "BirdFlowPipeline"))
html <- file.path(tempdir(), "index.html")
make_flux_index(index, html)
file.exists(html)
file.remove(html)
} # }