Process and fit a single model with fixed parameters
preprocess_and_fit.RdProcess and fit a single model with fixed parameters
Arguments
- species
A species code appropriate for
ebirdst::get_species().- params
A parameter list similar to that returned by
set_pipeline_params()but for this function each of thegrid_searchparameter list items should be a single value.