Calculate route summary statistics
rts_stats.RdCalculate route summary statistics
Arguments
- rts
BirdFlowRoutes object output from
BirdFlowR::route()or a data frame with the same data.- remove_head_and_tail_stationaries
Whether to remove the head and tail Stationary period. Useful when the calculaton is across multiple seasons ( e.g., From nonbreeding to breeding)